aboutsummaryrefslogtreecommitdiffstats
path: root/epan
diff options
context:
space:
mode:
authorGerald Combs <gerald@wireshark.org>2018-12-05 09:59:23 -0800
committerAnders Broman <a.broman58@gmail.com>2018-12-05 18:58:19 +0000
commit8c22c5badecf16c2a7881db28254ba22c7cb3d1c (patch)
treeedbdc500b9641bfbee4e7ab738d58d4fb5599b46 /epan
parent8cee907bbdfe94c133f1ed97174acfb3d814f369 (diff)
Fix some spelling errors found by Lintian.
Change-Id: If6fc3aab7ad4fc634567121f7b9541bc6f6c5766 Reviewed-on: https://code.wireshark.org/review/30926 Reviewed-by: Gerald Combs <gerald@wireshark.org> Petri-Dish: Gerald Combs <gerald@wireshark.org> Tested-by: Petri Dish Buildbot Reviewed-by: Anders Broman <a.broman58@gmail.com>
Diffstat (limited to 'epan')
-rw-r--r--epan/crypt/dot11decrypt.c2
-rw-r--r--epan/dissectors/asn1/tcap/packet-tcap-template.c2
-rw-r--r--epan/dissectors/file-elf.c2
-rw-r--r--epan/dissectors/packet-at.c4
-rw-r--r--epan/dissectors/packet-bgp.c2
-rw-r--r--epan/dissectors/packet-capwap.c2
-rw-r--r--epan/dissectors/packet-cdma2k.c14
-rw-r--r--epan/dissectors/packet-cql.c2
-rw-r--r--epan/dissectors/packet-dcerpc-dce122.c2
-rw-r--r--epan/dissectors/packet-dcerpc-netlogon.c2
-rw-r--r--epan/dissectors/packet-dis.c2
-rw-r--r--epan/dissectors/packet-dvbci.c4
-rw-r--r--epan/dissectors/packet-f5ethtrailer.c2
-rw-r--r--epan/dissectors/packet-gluster_pmap.c2
-rw-r--r--epan/dissectors/packet-glusterfs.c4
-rw-r--r--epan/dissectors/packet-gsm_a_dtap.c8
-rw-r--r--epan/dissectors/packet-gtp.c4
-rw-r--r--epan/dissectors/packet-h248_7.c2
-rw-r--r--epan/dissectors/packet-homeplug-av.c4
-rw-r--r--epan/dissectors/packet-ieee80211.c2
-rw-r--r--epan/dissectors/packet-iso15765.c2
-rw-r--r--epan/dissectors/packet-isobus-vt.c2
-rw-r--r--epan/dissectors/packet-llrp.c2
-rw-r--r--epan/dissectors/packet-lltd.c2
-rw-r--r--epan/dissectors/packet-ncp2222.inc6
-rw-r--r--epan/dissectors/packet-ndps.h2
-rw-r--r--epan/dissectors/packet-nettl.c2
-rw-r--r--epan/dissectors/packet-nfapi.c4
-rw-r--r--epan/dissectors/packet-nvme-rdma.c2
-rw-r--r--epan/dissectors/packet-oer.c18
-rw-r--r--epan/dissectors/packet-ospf.c2
-rw-r--r--epan/dissectors/packet-rtcp.c2
-rw-r--r--epan/dissectors/packet-rtp-midi.c2
-rw-r--r--epan/dissectors/packet-sccp.c2
-rw-r--r--epan/dissectors/packet-smb.c2
-rw-r--r--epan/dissectors/packet-srt.c2
-rw-r--r--epan/dissectors/packet-tcap.c2
-rw-r--r--epan/dissectors/packet-tds.c4
-rw-r--r--epan/dissectors/packet-usb.c2
-rw-r--r--epan/dissectors/packet-zbee-zcl-general.c4
-rw-r--r--epan/dissectors/packet-zbee-zcl-se.c22
-rw-r--r--epan/dissectors/packet-zebra.c12
-rw-r--r--epan/dissectors/usb.c14
-rw-r--r--epan/ftypes/ftypes.h2
-rw-r--r--epan/ipproto.h2
45 files changed, 93 insertions, 93 deletions
diff --git a/epan/crypt/dot11decrypt.c b/epan/crypt/dot11decrypt.c
index f26b6c0d7b..21e09c981c 100644
--- a/epan/crypt/dot11decrypt.c
+++ b/epan/crypt/dot11decrypt.c
@@ -722,7 +722,7 @@ static INT Dot11DecryptScanForKeys(
}
status=pntoh16(data+offset);
if (status != 0 && status != 85) {
- DOT11DECRYPT_DEBUG_PRINT_LINE("Dot11DecryptScanForKeys", "TDLS setup not successfull", DOT11DECRYPT_DEBUG_LEVEL_3);
+ DOT11DECRYPT_DEBUG_PRINT_LINE("Dot11DecryptScanForKeys", "TDLS setup not successful", DOT11DECRYPT_DEBUG_LEVEL_3);
return DOT11DECRYPT_RET_NO_VALID_HANDSHAKE;
}
diff --git a/epan/dissectors/asn1/tcap/packet-tcap-template.c b/epan/dissectors/asn1/tcap/packet-tcap-template.c
index 323dd07e57..90b6639cd1 100644
--- a/epan/dissectors/asn1/tcap/packet-tcap-template.c
+++ b/epan/dissectors/asn1/tcap/packet-tcap-template.c
@@ -2058,7 +2058,7 @@ proto_register_tcap(void)
prefs_register_uint_preference(tcap_module, "repetitiontimeout",
"Repetition timeout",
- "Maximal delay for message repetion",
+ "Maximal delay for message repetition",
10, &gtcap_RepetitionTimeout);
prefs_register_uint_preference(tcap_module, "losttimeout",
diff --git a/epan/dissectors/file-elf.c b/epan/dissectors/file-elf.c
index 9ba7e05a1a..07f1fc5126 100644
--- a/epan/dissectors/file-elf.c
+++ b/epan/dissectors/file-elf.c
@@ -2336,7 +2336,7 @@ proto_register_elf(void)
NULL, HFILL }
},
{ &hf_elf_symbol_table_shndx,
- { "Releated Section Header Index", "elf.symbol_table.shndx",
+ { "Related Section Header Index", "elf.symbol_table.shndx",
FT_UINT16, BASE_HEX | BASE_RANGE_STRING, RVALS(symbol_table_shndx_rvals), 0x00,
NULL, HFILL }
},
diff --git a/epan/dissectors/packet-at.c b/epan/dissectors/packet-at.c
index 63aa8245e6..571947a47d 100644
--- a/epan/dissectors/packet-at.c
+++ b/epan/dissectors/packet-at.c
@@ -191,8 +191,8 @@ static const value_string cfun_fun_vals[] = {
};
static const value_string cfun_rst_vals[] = {
- { 0, "Do not reset the MT before setting it to the requsted power level" },
- { 1, "Reset the MT before setting it to the requsted power level" },
+ { 0, "Do not reset the MT before setting it to the requested power level" },
+ { 1, "Reset the MT before setting it to the requested power level" },
{ 0, NULL }
};
diff --git a/epan/dissectors/packet-bgp.c b/epan/dissectors/packet-bgp.c
index 8d3107c344..e0f4f04241 100644
--- a/epan/dissectors/packet-bgp.c
+++ b/epan/dissectors/packet-bgp.c
@@ -7671,7 +7671,7 @@ dissect_bgp_path_attr(proto_tree *subtree, tvbuff_t *tvb, guint16 path_attr_len,
break;
default:
proto_tree_add_expert_format(subtree2, pinfo, &ei_bgp_prefix_sid_type_err, tvb, o + i + aoff, alen,
- "Unknwon BGP Prefix-SID TLV type: %u", prefix_sid_subtype);
+ "Unknown BGP Prefix-SID TLV type: %u", prefix_sid_subtype);
q += 3 + prefix_sid_sublen;
break;
}
diff --git a/epan/dissectors/packet-capwap.c b/epan/dissectors/packet-capwap.c
index abdc694f55..f92193988d 100644
--- a/epan/dissectors/packet-capwap.c
+++ b/epan/dissectors/packet-capwap.c
@@ -3546,7 +3546,7 @@ proto_register_capwap_control(void)
NULL, HFILL }
},
{ &hf_capwap_header_padding,
- { "Padding for 4 Byte Alignement", "capwap.header.padding",
+ { "Padding for 4 Byte Alignment", "capwap.header.padding",
FT_BYTES, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
diff --git a/epan/dissectors/packet-cql.c b/epan/dissectors/packet-cql.c
index dafdd1c3ce..fd61223b04 100644
--- a/epan/dissectors/packet-cql.c
+++ b/epan/dissectors/packet-cql.c
@@ -1107,7 +1107,7 @@ dissect_cql_tcp_pdu(tvbuff_t* raw_tvb, packet_info* pinfo, proto_tree* tree, voi
/* Now re-setup the tvb buffer to have the new data */
tvb = tvb_new_child_real_data(raw_tvb, decompressed_buffer, orig_size, orig_size);
add_new_data_source(pinfo, tvb, "Decompressed Data");
- /* mark the decompression as successfull */
+ /* mark the decompression as successful */
compression_level = CQL_COMPRESSION_LZ4;
message_length= orig_size;
}
diff --git a/epan/dissectors/packet-dcerpc-dce122.c b/epan/dissectors/packet-dcerpc-dce122.c
index 5505a8a60d..271d9016d3 100644
--- a/epan/dissectors/packet-dcerpc-dce122.c
+++ b/epan/dissectors/packet-dcerpc-dce122.c
@@ -142,7 +142,7 @@ static const value_string dce_error_vals[] = {
{ 546545692, "No more dumps on this tape" },
{ 546586625, "interface incompatible" },
{ 546586626, "there is not a mounted tape" },
- { 546586627, "multiple simulataneous mounts not permitted" },
+ { 546586627, "multiple simultaneous mounts not permitted" },
{ 546586628, "can't mount tape" },
{ 546586629, "error during tape dismount" },
{ 546586630, "tape I/O error" },
diff --git a/epan/dissectors/packet-dcerpc-netlogon.c b/epan/dissectors/packet-dcerpc-netlogon.c
index bb25f76794..753938ae5f 100644
--- a/epan/dissectors/packet-dcerpc-netlogon.c
+++ b/epan/dissectors/packet-dcerpc-netlogon.c
@@ -8620,7 +8620,7 @@ proto_register_dcerpc_netlogon(void)
{ "Avoid replication account database", "ntlmssp.neg_flags.na1000", FT_BOOLEAN, 32, TFS(&tfs_set_notset), NETLOGON_FLAG_1000, NULL, HFILL }},
{ &hf_netlogon_neg_flags_800,
- { "Concurent RPC", "ntlmssp.neg_flags.na800", FT_BOOLEAN, 32, TFS(&tfs_set_notset), NETLOGON_FLAG_800, NULL, HFILL }},
+ { "Concurrent RPC", "ntlmssp.neg_flags.na800", FT_BOOLEAN, 32, TFS(&tfs_set_notset), NETLOGON_FLAG_800, NULL, HFILL }},
{ &hf_netlogon_neg_flags_400,
{ "Generic pass-through", "ntlmssp.neg_flags.na400", FT_BOOLEAN, 32, TFS(&tfs_set_notset), NETLOGON_FLAG_400, NULL, HFILL }},
diff --git a/epan/dissectors/packet-dis.c b/epan/dissectors/packet-dis.c
index f871cc18a4..9387069d51 100644
--- a/epan/dissectors/packet-dis.c
+++ b/epan/dissectors/packet-dis.c
@@ -8764,7 +8764,7 @@ void proto_register_dis(void)
NULL, HFILL }
},
{ &hf_dis_pseudo_noise_modulation,
- { "Psuedo noise modulation", "dis.radio.mod_type.pseudo_noise_modulation",
+ { "Pseudo noise modulation", "dis.radio.mod_type.pseudo_noise_modulation",
FT_BOOLEAN, 16, TFS(&dis_pseudo_noise_value),0x0002,
NULL, HFILL }
},
diff --git a/epan/dissectors/packet-dvbci.c b/epan/dissectors/packet-dvbci.c
index 0ef6361eb0..1d360a09e0 100644
--- a/epan/dissectors/packet-dvbci.c
+++ b/epan/dissectors/packet-dvbci.c
@@ -1214,7 +1214,7 @@ static const value_string dvbci_cis_tpl_code[] = {
{ CISTPL_CFTABLE_ENTRY, "Configuration-table entry" },
{ CISTPL_DEVICE_OC, "Device information for Common Memory" },
{ CISTPL_DEVICE_OA, "Device information for Attribute Memory" },
- { CISTPL_MANFID, "Manufacturer indentification string" },
+ { CISTPL_MANFID, "Manufacturer identification string" },
{ CISTPL_END, "End of chain" },
{ 0, NULL }
};
@@ -1323,7 +1323,7 @@ static const value_string dvbci_res_class[] = {
};
static const value_string dvbci_app_type[] = {
{ APP_TYPE_CA, "Conditional Access" },
- { APP_TYPE_EPG, "Electronic Progam Guide" },
+ { APP_TYPE_EPG, "Electronic Program Guide" },
{ 0, NULL }
};
static const value_string dvbci_data_rate[] = {
diff --git a/epan/dissectors/packet-f5ethtrailer.c b/epan/dissectors/packet-f5ethtrailer.c
index a3edba26de..0721c67ec8 100644
--- a/epan/dissectors/packet-f5ethtrailer.c
+++ b/epan/dissectors/packet-f5ethtrailer.c
@@ -3153,7 +3153,7 @@ void proto_register_f5ethtrailer (void)
" tcp.port and udp.port). Enabling this will allow filters that"
" reference those fields to also find data in the trailers but"
" will reduce performance. After disabling, you should restart"
- " Wireshark to get perfomance back.", &pop_other_fields);
+ " Wireshark to get performance back.", &pop_other_fields);
#else
/* If we are not building with this, silently delete the preference */
prefs_register_obsolete_preference(f5ethtrailer_module,
diff --git a/epan/dissectors/packet-gluster_pmap.c b/epan/dissectors/packet-gluster_pmap.c
index b5ad5e90e5..3ab3b1f0f1 100644
--- a/epan/dissectors/packet-gluster_pmap.c
+++ b/epan/dissectors/packet-gluster_pmap.c
@@ -86,7 +86,7 @@ gluster_dump_reply_detail(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
const gchar *progname = NULL;
detail_tree = proto_tree_add_subtree(tree, tvb, offset, -1,
- ett_gluster_dump_detail, &detail_item, "Available Progam: ");
+ ett_gluster_dump_detail, &detail_item, "Available Program: ");
/* progname */
offset = dissect_rpc_string(tvb, detail_tree, hf_gluster_progname,
diff --git a/epan/dissectors/packet-glusterfs.c b/epan/dissectors/packet-glusterfs.c
index be819c6157..25970dbe36 100644
--- a/epan/dissectors/packet-glusterfs.c
+++ b/epan/dissectors/packet-glusterfs.c
@@ -4028,11 +4028,11 @@ proto_register_glusterfs(void)
0, NULL, HFILL }
},
{ &hf_glusterfs_iax_attributes,
- { "IATT atributes", "glusterfs.iax_attributes", FT_UINT64,
+ { "IATT attributes", "glusterfs.iax_attributes", FT_UINT64,
BASE_HEX, NULL, 0, NULL, HFILL }
},
{ &hf_glusterfs_iax_attributes_mask,
- { "IATT atributes mask", "glusterfs.iax_attributes_mask", FT_UINT64,
+ { "IATT attributes mask", "glusterfs.iax_attributes_mask", FT_UINT64,
BASE_HEX, NULL, 0, NULL, HFILL }
},
{ &hf_glusterfs_iax_flags,
diff --git a/epan/dissectors/packet-gsm_a_dtap.c b/epan/dissectors/packet-gsm_a_dtap.c
index d15e219301..5ec006c817 100644
--- a/epan/dissectors/packet-gsm_a_dtap.c
+++ b/epan/dissectors/packet-gsm_a_dtap.c
@@ -1321,7 +1321,7 @@ de_mm_timer(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo _U_, guint32 off
* [3] 10.5.4.4 Auxiliary states
*/
-static const value_string gsm_a_dtap_hold_auxilary_state_vals[] = {
+static const value_string gsm_a_dtap_hold_auxiliary_state_vals[] = {
{ 0x00, "Idle" },
{ 0x01, "Hold request" },
{ 0x02, "Call held" },
@@ -1329,7 +1329,7 @@ static const value_string gsm_a_dtap_hold_auxilary_state_vals[] = {
{ 0, NULL }
};
-static const value_string gsm_a_dtap_multi_party_auxilary_state_vals[] = {
+static const value_string gsm_a_dtap_multi_party_auxiliary_state_vals[] = {
{ 0x00, "Idle" },
{ 0x01, "MPTY request" },
{ 0x02, "Call in MPTY" },
@@ -7874,12 +7874,12 @@ proto_register_gsm_a_dtap(void)
},
{ &hf_gsm_a_dtap_hold_auxiliary_state,
{ "Hold auxiliary state", "gsm_a.dtap.hold_auxiliary_state",
- FT_UINT8, BASE_DEC, VALS(gsm_a_dtap_hold_auxilary_state_vals), 0x0C,
+ FT_UINT8, BASE_DEC, VALS(gsm_a_dtap_hold_auxiliary_state_vals), 0x0C,
NULL, HFILL }
},
{ &hf_gsm_a_dtap_multi_party_auxiliary_state,
{ "Multi party auxiliary state", "gsm_a.dtap.multi_party_auxiliary_state",
- FT_UINT8, BASE_DEC, VALS(gsm_a_dtap_multi_party_auxilary_state_vals), 0x03,
+ FT_UINT8, BASE_DEC, VALS(gsm_a_dtap_multi_party_auxiliary_state_vals), 0x03,
NULL, HFILL }
},
{ &hf_gsm_a_dtap_radio_channel_requirement,
diff --git a/epan/dissectors/packet-gtp.c b/epan/dissectors/packet-gtp.c
index 72faceeb72..66201a93ba 100644
--- a/epan/dissectors/packet-gtp.c
+++ b/epan/dissectors/packet-gtp.c
@@ -3125,7 +3125,7 @@ static _gtp_mess_items umts_mess_items[] = {
{GTP_EXT_RAT_TYPE, GTP_OPTIONAL}, /* RAT Type Optional 7.7.50 */
{GTP_EXT_USR_LOC_INF, GTP_OPTIONAL}, /* User Location Information Optional 7.7.51 */
{GTP_EXT_MS_TIME_ZONE, GTP_OPTIONAL}, /* MS Time Zone Optional 7.7.52 */
- {GTP_EXT_ADD_TRS_INF, GTP_OPTIONAL}, /* Additonal Trace Info Optional 7.7.62 */
+ {GTP_EXT_ADD_TRS_INF, GTP_OPTIONAL}, /* Additional Trace Info Optional 7.7.62 */
{GTP_EXT_DIRECT_TUNNEL_FLGS, GTP_OPTIONAL}, /* Direct Tunnel Flags 7.7.81 */
{GTP_EXT_PRIV_EXT, GTP_OPTIONAL},
{0, 0}
@@ -3482,7 +3482,7 @@ static _gtp_mess_items umts_mess_items[] = {
{GTP_EXT_MS_TIME_ZONE, GTP_OPTIONAL}, /* MS Time Zone Optional 7.7.52 */
{GTP_EXT_IMEISV, GTP_OPTIONAL}, /* IMEI(SV) Optional 7.7.53 */
{GTP_EXT_MBMS_PROT_CONF_OPT, GTP_OPTIONAL}, /* MBMS Protocol Configuration Options Optional 7.7.58 */
- {GTP_EXT_ADD_TRS_INF, GTP_OPTIONAL}, /* Additonal Trace Info Optional 7.7.62 */
+ {GTP_EXT_ADD_TRS_INF, GTP_OPTIONAL}, /* Additional Trace Info Optional 7.7.62 */
{GTP_EXT_ENH_NSAPI, GTP_MANDATORY}, /* Enhanced NSAPI Mandatory 7.7.67 */
{GTP_EXT_ADD_MBMS_TRS_INF, GTP_OPTIONAL}, /* Additional MBMS Trace Info Optional 7.7.68 */
{GTP_EXT_PRIV_EXT, GTP_OPTIONAL},
diff --git a/epan/dissectors/packet-h248_7.c b/epan/dissectors/packet-h248_7.c
index 048fef1f5d..7df4098286 100644
--- a/epan/dissectors/packet-h248_7.c
+++ b/epan/dissectors/packet-h248_7.c
@@ -44,7 +44,7 @@ static gint ett_h248_an_apf = -1;
static gint ett_h248_an_apv = -1;
static const value_string h248_an_prop_vals[] = {
- { 0, "Generic Announcment Package (an) (H.248.7)" },
+ { 0, "Generic Announcement Package (an) (H.248.7)" },
{ 0, NULL }
};
diff --git a/epan/dissectors/packet-homeplug-av.c b/epan/dissectors/packet-homeplug-av.c
index 388cf5c7ff..e7903580d2 100644
--- a/epan/dissectors/packet-homeplug-av.c
+++ b/epan/dissectors/packet-homeplug-av.c
@@ -4822,11 +4822,11 @@ proto_register_homeplug_av(void)
FT_UINT64, BASE_DEC, NULL, 0x00, NULL, HFILL }
},
{ &hf_homeplug_av_lnk_stats_rx_tb_pass,
- { "Sum of Turbo Bit Error over successfully recevied PBs", "homeplug_av.lnk_stats.rx.tb_pass",
+ { "Sum of Turbo Bit Error over successfully received PBs", "homeplug_av.lnk_stats.rx.tb_pass",
FT_UINT64, BASE_DEC, NULL, 0x00, NULL, HFILL }
},
{ &hf_homeplug_av_lnk_stats_rx_tb_fail,
- { "Sum of Turbo Bit Error over unsuccessfully recevied PBs", "homeplug_av.lnk_stats.rx.tb_fail",
+ { "Sum of Turbo Bit Error over unsuccessfully received PBs", "homeplug_av.lnk_stats.rx.tb_fail",
FT_UINT64, BASE_DEC, NULL, 0x00, NULL, HFILL }
},
{ &hf_homeplug_av_lnk_stats_rx_num_int,
diff --git a/epan/dissectors/packet-ieee80211.c b/epan/dissectors/packet-ieee80211.c
index 5ce8fbed57..ec74768f05 100644
--- a/epan/dissectors/packet-ieee80211.c
+++ b/epan/dissectors/packet-ieee80211.c
@@ -34139,7 +34139,7 @@ proto_register_ieee80211(void)
{&hf_he_qtp_response_quiet_period_interval,
{"Quiet Period Interval", "wlan.ext_tag.quiet_time_period.response.interval",
FT_UINT8, BASE_DEC, NULL, 0,
- "Interval between the start of two consequtive quiet time periods", HFILL } },
+ "Interval between the start of two consecutive quiet time periods", HFILL } },
{&hf_he_qtp_response_repetition_count,
{"Repetition Count", "wlan.ext_tag.quiet_time_period.response.repetition_count",
diff --git a/epan/dissectors/packet-iso15765.c b/epan/dissectors/packet-iso15765.c
index 9ebbbf1cf9..efec79f6d5 100644
--- a/epan/dissectors/packet-iso15765.c
+++ b/epan/dissectors/packet-iso15765.c
@@ -257,7 +257,7 @@ dissect_iso15765(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data
ae + ISO15765_FC_BS_OFFSET, ISO15765_FC_BS_LEN, ENC_BIG_ENDIAN);
proto_tree_add_item(iso15765_tree, hf_iso15765_fc_stmin, tvb,
ae + ISO15765_FC_STMIN_OFFSET, ISO15765_FC_STMIN_LEN, ENC_BIG_ENDIAN);
- col_append_fstr(pinfo->cinfo, COL_INFO, "(Status: %d, Block size:0x%x, Seperation time minimum: %d ms)",
+ col_append_fstr(pinfo->cinfo, COL_INFO, "(Status: %d, Block size:0x%x, Separation time minimum: %d ms)",
status, bs, stmin);
break;
}
diff --git a/epan/dissectors/packet-isobus-vt.c b/epan/dissectors/packet-isobus-vt.c
index 79f1c1fb14..28d12d81f5 100644
--- a/epan/dissectors/packet-isobus-vt.c
+++ b/epan/dissectors/packet-isobus-vt.c
@@ -795,7 +795,7 @@ static const value_string select_input_opject_response[] = {
static const value_string draw_text_background[] = {
{ 0, "Opaque" },
- { 1, "Transparant" },
+ { 1, "Transparent" },
{ 0, NULL }
};
diff --git a/epan/dissectors/packet-llrp.c b/epan/dissectors/packet-llrp.c
index c105708430..15ac2a5285 100644
--- a/epan/dissectors/packet-llrp.c
+++ b/epan/dissectors/packet-llrp.c
@@ -3122,7 +3122,7 @@ proto_register_llrp(void)
/* TODO add translation */
{ &hf_llrp_country_code,
- { "Contry code", "llrp.param.country_code", FT_UINT16, BASE_DEC, NULL, 0,
+ { "Country code", "llrp.param.country_code", FT_UINT16, BASE_DEC, NULL, 0,
NULL, HFILL }},
{ &hf_llrp_comm_standard,
diff --git a/epan/dissectors/packet-lltd.c b/epan/dissectors/packet-lltd.c
index fe7a614742..5759c38274 100644
--- a/epan/dissectors/packet-lltd.c
+++ b/epan/dissectors/packet-lltd.c
@@ -223,7 +223,7 @@ static const value_string lltd_tlv_type_vals[] = {
{ 0x12, "Device UUID" },
{ 0x13, "Hardware ID" },
{ 0x14, "QoS Characteristics" },
- { 0x15, "802.11 Phyiscal Medium" },
+ { 0x15, "802.11 Physical Medium" },
{ 0x16, "AP Association Table" },
{ 0x18, "Detailed Icon Image" },
{ 0x19, "Sees-List Working Set" },
diff --git a/epan/dissectors/packet-ncp2222.inc b/epan/dissectors/packet-ncp2222.inc
index e7bb451f0b..3c1938e6c9 100644
--- a/epan/dissectors/packet-ncp2222.inc
+++ b/epan/dissectors/packet-ncp2222.inc
@@ -1290,7 +1290,7 @@ static const value_string nds_reply_errors[] = {
{ 0xfffffd5f, "(-673) Replica Not On" },
{ 0xfffffd5e, "(-674) Invalid Name Service" },
{ 0xfffffd5d, "(-675) Invalid Task" },
- { 0xfffffd5c, "(-676) Invalide Connection Handle" },
+ { 0xfffffd5c, "(-676) Invalid Connection Handle" },
{ 0xfffffd5b, "(-677) Invalid Identity" },
{ 0xfffffd5a, "(-678) Duplicate ACL" },
{ 0xfffffd59, "(-679) Partition Already Exists" },
@@ -1327,7 +1327,7 @@ static const value_string nds_reply_errors[] = {
{ 0xfffffd3a, "(-710) Database Read Fail" },
{ 0xfffffd39, "(-711) Invalid Code Page" },
{ 0xfffffd38, "(-712) Invalid Escape Character" },
- { 0xfffffd37, "(-713) Invalide Delimiters" },
+ { 0xfffffd37, "(-713) Invalid Delimiters" },
{ 0xfffffd36, "(-714) Not Implemented" },
{ 0xfffffd35, "(-715) Checksum Failure" },
{ 0xfffffd34, "(-716) Checksumming Not Supported" },
@@ -8488,7 +8488,7 @@ dissect_nds_request(tvbuff_t *tvb, packet_info *pinfo,
value1 = tvb_get_letohl(tvb, foffset);
if ((value1 & 0xf000) == 0xc000)
{
- proto_tree_add_string(ncp_tree, hf_nds_name_type, tvb, 0, 0, "Return Partion Name");
+ proto_tree_add_string(ncp_tree, hf_nds_name_type, tvb, 0, 0, "Return Partition Name");
}
else
{
diff --git a/epan/dissectors/packet-ndps.h b/epan/dissectors/packet-ndps.h
index 507307567a..3cb618ae6d 100644
--- a/epan/dissectors/packet-ndps.h
+++ b/epan/dissectors/packet-ndps.h
@@ -1686,7 +1686,7 @@ static const value_string object_ids_15[] = { /* 060F6086 480186F837 (LENGTH 15)
{ 0x01090210, "(Novell) Attribute PRINTER OUTPUT MAXIMUM DIMENSION TRANSFER FEED DIRECTION" },
{ 0x01090211, "(Novell) Attribute PRINTER OUTPUT MINIMUM DIMENSION FEED DIRECTION" },
{ 0x01090212, "(Novell) Attribute PRINTER OUTPUT MINIMUM DIMENSION TRANSFER FEED DIRECTION" },
- { 0x01090213, "(Novell) Attribute PRINTER OUTPUT STACK INGORE DER" },
+ { 0x01090213, "(Novell) Attribute PRINTER OUTPUT STACK IGNORE DER" },
{ 0x01090214, "(Novell) Attribute PRINTER OUTPUT PAGE DELIVERY ENTRY" },
{ 0x01090215, "(Novell) Attribute PRINTER OUTPUT BURSTING" },
{ 0x01090216, "(Novell) Attribute PRINTER OUTPUT DECOLLATING" },
diff --git a/epan/dissectors/packet-nettl.c b/epan/dissectors/packet-nettl.c
index 3e29599418..2e8e0ab29f 100644
--- a/epan/dissectors/packet-nettl.c
+++ b/epan/dissectors/packet-nettl.c
@@ -261,7 +261,7 @@ dissect_nettl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U
break;
default:
col_set_str(pinfo->cinfo, COL_PROTOCOL, "UNKNOWN");
- col_add_fstr(pinfo->cinfo, COL_INFO, "Unsupported nettl subsytem: %d (%s)",
+ col_add_fstr(pinfo->cinfo, COL_INFO, "Unsupported nettl subsystem: %d (%s)",
pinfo->pseudo_header->nettl.subsys,
val_to_str_ext_const(pinfo->pseudo_header->nettl.subsys, &subsystem_ext, "Unknown"));
call_data_dissector(tvb, pinfo, tree);
diff --git a/epan/dissectors/packet-nfapi.c b/epan/dissectors/packet-nfapi.c
index fade9368b2..3c95c88991 100644
--- a/epan/dissectors/packet-nfapi.c
+++ b/epan/dissectors/packet-nfapi.c
@@ -1615,7 +1615,7 @@ static void dissect_pnf_phy_instance_value(ptvcursor_t * ptvc, packet_info* pinf
hf_nfapi_uplink_channel_bandwidth_supported, ett_nfapi_uplink_bandwidth_support, ul_bandwidth_support_fields, ENC_BIG_ENDIAN, &test_value64);
if (test_value64 > 0x3F)
{
- expert_add_info_format(pinfo, item, &ei_invalid_range, "Invalid uplink channel bandwidht supported bits [0..0x3F]");
+ expert_add_info_format(pinfo, item, &ei_invalid_range, "Invalid uplink channel bandwidth supported bits [0..0x3F]");
}
ptvcursor_advance(ptvc, 2);
@@ -10444,7 +10444,7 @@ void proto_register_nfapi(void)
{ &hf_nfapi_laa_end_partial_sf_flag,
{ "LAA end partial SF flag", "nfapi.laa.end.partial.sf.flag",
FT_UINT8, BASE_DEC, NULL, 0x0,
- "Indicates if DCI format 1C is being used to signal LAA end partial SF (valid if end partial SF support configuraton is set)", HFILL }
+ "Indicates if DCI format 1C is being used to signal LAA end partial SF (valid if end partial SF support configuration is set)", HFILL }
},
{ &hf_nfapi_laa_end_partial_sf_configuration,
{ "LAA end partial SF configuration", "nfapi.laa.end.partial.sf.configuration",
diff --git a/epan/dissectors/packet-nvme-rdma.c b/epan/dissectors/packet-nvme-rdma.c
index 9e029e5ae9..b2af271aee 100644
--- a/epan/dissectors/packet-nvme-rdma.c
+++ b/epan/dissectors/packet-nvme-rdma.c
@@ -1105,7 +1105,7 @@ proto_register_nvme_rdma(void)
{ &hf_nvme_rdma_cmd_qid,
{ "Cmd Qid", "nvme-rdma.cmd.qid",
FT_UINT16, BASE_HEX, NULL, 0x0,
- "Qid on which comamnd is issued", HFILL }
+ "Qid on which command is issued", HFILL }
},
};
static gint *ett[] = {
diff --git a/epan/dissectors/packet-oer.c b/epan/dissectors/packet-oer.c
index e23f6ae8dc..5c81cdbf70 100644
--- a/epan/dissectors/packet-oer.c
+++ b/epan/dissectors/packet-oer.c
@@ -537,7 +537,7 @@ dissect_oer_sequence_of(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_t
proto_item *item;
proto_tree *tree;
guint32 old_offset = offset;
- guint32 occ_len, occurence;
+ guint32 occ_len, occurrence;
header_field_info *hfi;
DEBUG_ENTRY("dissect_oer_sequence_of");
@@ -552,34 +552,34 @@ dissect_oer_sequence_of(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_t
switch (occ_len) {
case 1:
- occurence = tvb_get_guint8(tvb, offset);
+ occurrence = tvb_get_guint8(tvb, offset);
break;
case 2:
- occurence = tvb_get_ntohs(tvb, offset);
+ occurrence = tvb_get_ntohs(tvb, offset);
break;
case 3:
- occurence = tvb_get_ntoh24(tvb, offset);
+ occurrence = tvb_get_ntoh24(tvb, offset);
break;
case 4:
- occurence = tvb_get_ntohl(tvb, offset);
+ occurrence = tvb_get_ntohl(tvb, offset);
break;
default:
proto_tree_add_expert_format(parent_tree, actx->pinfo, &ei_oer_not_decoded_yet, tvb, offset, 1,
- "sequence_of Occurence %u octets not handled", occ_len);
+ "sequence_of Occurrence %u octets not handled", occ_len);
return tvb_reported_length(tvb);
}
offset = offset + occ_len;
hfi = proto_registrar_get_nth(hf_index);
if (IS_FT_UINT(hfi->type)) {
- item = proto_tree_add_uint(parent_tree, hf_index, tvb, old_offset, occ_len, occurence);
- proto_item_append_text(item, (occurence == 1) ? " item" : " items");
+ item = proto_tree_add_uint(parent_tree, hf_index, tvb, old_offset, occ_len, occurrence);
+ proto_item_append_text(item, (occurrence == 1) ? " item" : " items");
} else {
item = proto_tree_add_item(parent_tree, hf_index, tvb, old_offset, 0, ENC_BIG_ENDIAN);
}
tree = proto_item_add_subtree(item, ett_index);
- offset = dissect_oer_sequence_of_helper(tvb, offset, actx, tree, seq->func, *seq->p_id, occurence);
+ offset = dissect_oer_sequence_of_helper(tvb, offset, actx, tree, seq->func, *seq->p_id, occurrence);
proto_item_set_len(item, offset - old_offset);
diff --git a/epan/dissectors/packet-ospf.c b/epan/dissectors/packet-ospf.c
index 13a2c1b45d..c009b37927 100644
--- a/epan/dissectors/packet-ospf.c
+++ b/epan/dissectors/packet-ospf.c
@@ -12,7 +12,7 @@
* At this time, this module is able to analyze OSPF
* packets as specified in RFC2328. MOSPF (RFC1584) and other
* OSPF Extensions which introduce new Packet types
- * (e.g the External Atributes LSA) are not supported.
+ * (e.g the External Attributes LSA) are not supported.
* Furthermore RFC2740 (OSPFv3 - OSPF for IPv6) is now supported
* - (c) 2001 Palle Lyckegaard <palle[AT]lyckegaard.dk>
*
diff --git a/epan/dissectors/packet-rtcp.c b/epan/dissectors/packet-rtcp.c
index 851dedaef8..5619311741 100644
--- a/epan/dissectors/packet-rtcp.c
+++ b/epan/dissectors/packet-rtcp.c
@@ -5568,7 +5568,7 @@ proto_register_rtcp(void)
{
&hf_rtcp_xr_idms_spst,
{
- "Syncronization Packet Sender Type",
+ "Synchronization Packet Sender Type",
"rtcp.xr.idms.spst",
FT_UINT8,
BASE_DEC,
diff --git a/epan/dissectors/packet-rtp-midi.c b/epan/dissectors/packet-rtp-midi.c
index 5ee2c88623..26df87ab92 100644
--- a/epan/dissectors/packet-rtp-midi.c
+++ b/epan/dissectors/packet-rtp-midi.c
@@ -9343,7 +9343,7 @@ proto_register_rtp_midi( void )
{
&hf_rtp_midi_sysex_common_nrt_sd_packet_check,
{
- "Sysex Common Non-Realtime Sample Dump Checkum",
+ "Sysex Common Non-Realtime Sample Dump Checksum",
"rtpmidi.sysex_common_non_realtime_sample_dump_checksum",
FT_UINT8,
BASE_HEX,
diff --git a/epan/dissectors/packet-sccp.c b/epan/dissectors/packet-sccp.c
index d3f0d59497..a0b946c2da 100644
--- a/epan/dissectors/packet-sccp.c
+++ b/epan/dissectors/packet-sccp.c
@@ -1808,7 +1808,7 @@ dissect_sccp_global_title(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, g
"Global Title 0x%x (%u byte%s)",
gti, length, plurality(length,"", "s"));
- /* Decode Transation Type (if present) */
+ /* Decode Transaction Type (if present) */
if ((gti == AI_GTI_TT) ||
((decode_mtp3_standard != ANSI_STANDARD) &&
((gti == ITU_AI_GTI_TT_NP_ES) || (gti == ITU_AI_GTI_TT_NP_ES_NAI))) ||
diff --git a/epan/dissectors/packet-smb.c b/epan/dissectors/packet-smb.c
index 994734e926..a3b91cf7c1 100644
--- a/epan/dissectors/packet-smb.c
+++ b/epan/dissectors/packet-smb.c
@@ -21083,7 +21083,7 @@ proto_register_smb(void)
};
static ei_register_info ei[] = {
- { &ei_smb_mal_information_level, { "smb.information_level.malformed", PI_MALFORMED, PI_ERROR, "Information level structure goes past the end of the transation data.", EXPFILL }},
+ { &ei_smb_mal_information_level, { "smb.information_level.malformed", PI_MALFORMED, PI_ERROR, "Information level structure goes past the end of the transaction data.", EXPFILL }},
{ &ei_smb_not_implemented, { "smb.not_implemented", PI_UNDECODED, PI_WARN, "Not Implemented yet", EXPFILL }},
{ &ei_smb_nt_transaction_setup, { "smb.nt_transaction_setup.unknown", PI_PROTOCOL, PI_NOTE, "Unknown NT Transaction Setup (matching request not seen)", EXPFILL }},
{ &ei_smb_posix_ace_type, { "smb.posix_acl.ace_type.unknown", PI_PROTOCOL, PI_WARN, "Unknown posix ace type", EXPFILL }},
diff --git a/epan/dissectors/packet-srt.c b/epan/dissectors/packet-srt.c
index 9ad2ea9f12..51fb857974 100644
--- a/epan/dissectors/packet-srt.c
+++ b/epan/dissectors/packet-srt.c
@@ -298,7 +298,7 @@ static const value_string srt_msgno_enctypes[] = {
};
static const true_false_string srt_msgno_rexmit = {
- "Retransmited", /* 1 */
+ "Retransmitted", /* 1 */
"Original" /* 0 */
};
diff --git a/epan/dissectors/packet-tcap.c b/epan/dissectors/packet-tcap.c
index 332295254c..2c1fe4a3d1 100644
--- a/epan/dissectors/packet-tcap.c
+++ b/epan/dissectors/packet-tcap.c
@@ -3656,7 +3656,7 @@ proto_register_tcap(void)
prefs_register_uint_preference(tcap_module, "repetitiontimeout",
"Repetition timeout",
- "Maximal delay for message repetion",
+ "Maximal delay for message repetition",
10, &gtcap_RepetitionTimeout);
prefs_register_uint_preference(tcap_module, "losttimeout",
diff --git a/epan/dissectors/packet-tds.c b/epan/dissectors/packet-tds.c
index b23a23fe7e..1b6885b08f 100644
--- a/epan/dissectors/packet-tds.c
+++ b/epan/dissectors/packet-tds.c
@@ -9390,12 +9390,12 @@ proto_register_tds(void)
NULL, HFILL }
},
{ &hf_tdslogin_halogin,
- { "High Availibility login", "tds.login.halogin",
+ { "High Availability login", "tds.login.halogin",
FT_BOOLEAN, BASE_NONE, TFS(&tfs_yes_no), 0x0,
NULL, HFILL }
},
{ &hf_tdslogin_hasessionid,
- { "High Availibility session id", "tds.login.hasessionid",
+ { "High Availability session id", "tds.login.hasessionid",
FT_BYTES, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
diff --git a/epan/dissectors/packet-usb.c b/epan/dissectors/packet-usb.c
index ba4ebdcd98..2538a22c30 100644
--- a/epan/dissectors/packet-usb.c
+++ b/epan/dissectors/packet-usb.c
@@ -4611,7 +4611,7 @@ netmon_fid_USBPORT_Endpoint_Descriptor(proto_tree *tree, tvbuff_t *tvb, int offs
{
proto_tree *endpoint_desc_tree;
- endpoint_desc_tree = proto_tree_add_subtree(tree, tvb, offset, 7, ett_usbport_endpoint_desc, NULL, "Endpoint Decriptor");
+ endpoint_desc_tree = proto_tree_add_subtree(tree, tvb, offset, 7, ett_usbport_endpoint_desc, NULL, "Endpoint Descriptor");
proto_tree_add_item(endpoint_desc_tree, hf_usbport_endpoint_desc_length, tvb, offset, 1, ENC_LITTLE_ENDIAN);
offset += 1;
proto_tree_add_item(endpoint_desc_tree, hf_usbport_endpoint_desc_type, tvb, offset, 1, ENC_LITTLE_ENDIAN);
diff --git a/epan/dissectors/packet-zbee-zcl-general.c b/epan/dissectors/packet-zbee-zcl-general.c
index 1c896abb4b..35e28113c9 100644
--- a/epan/dissectors/packet-zbee-zcl-general.c
+++ b/epan/dissectors/packet-zbee-zcl-general.c
@@ -9164,7 +9164,7 @@ proto_reg_handoff_zbee_zcl_commissioning(void)
/* Attributes */
#define ZBEE_ZCL_ATTR_ID_PART_MAX_IN_TRANSF_SIZE 0x0000 /* Maximum Incoming Transfer Size */
#define ZBEE_ZCL_ATTR_ID_PART_MAX_OUT_TRANSF_SIZE 0x0001 /* Maximum Outgoing Transfer Size */
-#define ZBEE_ZCL_ATTR_ID_PART_PARTIONED_FRAME_SIZE 0x0002 /* Partioned Frame Size */
+#define ZBEE_ZCL_ATTR_ID_PART_PARTITIONED_FRAME_SIZE 0x0002 /* Partitioned Frame Size */
#define ZBEE_ZCL_ATTR_ID_PART_LARGE_FRAME_SIZE 0x0003 /* Large Frame Size */
#define ZBEE_ZCL_ATTR_ID_PART_ACK_FRAME_NUM 0x0004 /* Number of Ack Frame*/
#define ZBEE_ZCL_ATTR_ID_PART_NACK_TIMEOUT 0x0005 /* Nack Timeout */
@@ -9233,7 +9233,7 @@ static gint ett_zbee_zcl_part_attrs_id_list[ZBEE_ZCL_PART_NUM_ATTRS_ID_ETT];
static const value_string zbee_zcl_part_attr_names[] = {
{ ZBEE_ZCL_ATTR_ID_PART_MAX_IN_TRANSF_SIZE, "Maximum Incoming Transfer Size" },
{ ZBEE_ZCL_ATTR_ID_PART_MAX_OUT_TRANSF_SIZE, "Maximum Outgoing Transfer Size" },
- { ZBEE_ZCL_ATTR_ID_PART_PARTIONED_FRAME_SIZE, "Partioned Frame Size" },
+ { ZBEE_ZCL_ATTR_ID_PART_PARTITIONED_FRAME_SIZE, "Partitioned Frame Size" },
{ ZBEE_ZCL_ATTR_ID_PART_LARGE_FRAME_SIZE, "Large Frame Size" },
{ ZBEE_ZCL_ATTR_ID_PART_ACK_FRAME_NUM, "Number of Ack Frame" },
{ ZBEE_ZCL_ATTR_ID_PART_NACK_TIMEOUT, "Nack Timeout" },
diff --git a/epan/dissectors/packet-zebra.c b/epan/dissectors/packet-zebra.c
index 4c11fe49f0..bf74446cbc 100644
--- a/epan/dissectors/packet-zebra.c
+++ b/epan/dissectors/packet-zebra.c
@@ -315,8 +315,8 @@ static const value_string frr_zapi4_messages[] = {
{ FRR_ZAPI4_INTERFACE_DISABLE_RADV, "Interface Disable Rouer Advertisement" },
{ FRR_ZAPI4_IPV4_NEXTHOP_LOOKUP_MRIB, "IPv4 Nexthop Lookup Multicast RIB" },
{ FRR_ZAPI4_INTERFACE_LINK_PARAMS, "Interface Link Paameters" },
- { FRR_ZAPI4_MPLS_LABELS_ADD, "MPLS Lables Add" },
- { FRR_ZAPI4_MPLS_LABELS_DELETE, "MPLS Lables Delete" },
+ { FRR_ZAPI4_MPLS_LABELS_ADD, "MPLS Labels Add" },
+ { FRR_ZAPI4_MPLS_LABELS_DELETE, "MPLS Labels Delete" },
{ FRR_ZAPI4_IPV4_NEXTHOP_ADD, "Add IPv4 Nexthop" },
{ FRR_ZAPI4_IPV4_NEXTHOP_DELETE, "Delete IPv4 Nexthop" },
{ FRR_ZAPI4_IPV6_NEXTHOP_ADD, "Add IPv6 Nexthop" },
@@ -478,8 +478,8 @@ static const value_string frr_zapi5_messages[] = {
{ FRR_ZAPI5_INTERFACE_DISABLE_RADV, "Interface Disable Rouer Advertisement" },
{ FRR_ZAPI5_IPV4_NEXTHOP_LOOKUP_MRIB, "IPv4 Nexthop Lookup Multicast RIB" },
{ FRR_ZAPI5_INTERFACE_LINK_PARAMS, "Interface Link Paameters" },
- { FRR_ZAPI5_MPLS_LABELS_ADD, "MPLS Lables Add" },
- { FRR_ZAPI5_MPLS_LABELS_DELETE, "MPLS Lables Delete" },
+ { FRR_ZAPI5_MPLS_LABELS_ADD, "MPLS Labels Add" },
+ { FRR_ZAPI5_MPLS_LABELS_DELETE, "MPLS Labels Delete" },
{ FRR_ZAPI5_IPMR_ROUTE_STATS, "IPMR Route Statics" },
{ FRR_ZAPI5_LABEL_MANAGER_CONNECT, "Label Manager Connect" },
{ FRR_ZAPI5_LABEL_MANAGER_CONNECT_ASYNC,"Label Manager Connect Asynchronous" },
@@ -666,8 +666,8 @@ static const value_string frr_zapi6_messages[] = {
{ FRR_ZAPI6_INTERFACE_DISABLE_RADV, "Interface Disable Rouer Advertisement" },
{ FRR_ZAPI6_IPV4_NEXTHOP_LOOKUP_MRIB, "IPv4 Nexthop Lookup Multicast RIB" },
{ FRR_ZAPI6_INTERFACE_LINK_PARAMS, "Interface Link Paameters" },
- { FRR_ZAPI6_MPLS_LABELS_ADD, "MPLS Lables Add" },
- { FRR_ZAPI6_MPLS_LABELS_DELETE, "MPLS Lables Delete" },
+ { FRR_ZAPI6_MPLS_LABELS_ADD, "MPLS Labels Add" },
+ { FRR_ZAPI6_MPLS_LABELS_DELETE, "MPLS Labels Delete" },
{ FRR_ZAPI6_IPMR_ROUTE_STATS, "IPMR Route Statics" },
{ FRR_ZAPI6_LABEL_MANAGER_CONNECT, "Label Manager Connect" },
{ FRR_ZAPI6_GET_LABEL_CHUNK, "Get Label Chunk" },
diff --git a/epan/dissectors/usb.c b/epan/dissectors/usb.c
index 42e561cfff..460b661a8e 100644
--- a/epan/dissectors/usb.c
+++ b/epan/dissectors/usb.c
@@ -5559,7 +5559,7 @@ static const value_string usb_products_vals[] = {
{ 0x046d08d7, "QuickCam Communicate STX" },
{ 0x046d08d8, "QuickCam for Notebook Deluxe" },
{ 0x046d08d9, "QuickCam IM/Connect" },
- { 0x046d08da, "QuickCam Messanger" },
+ { 0x046d08da, "QuickCam Messenger" },
{ 0x046d08dd, "QuickCam for Notebooks" },
{ 0x046d08e0, "QuickCam Express" },
{ 0x046d08e1, "Labtec Webcam" },
@@ -16689,7 +16689,7 @@ static const value_string usb_products_vals[] = {
{ 0x12091006, "Mini IO-Board" },
{ 0x12091ab5, "Arachnid Labs Tsunami" },
{ 0x12092000, "Zygmunt Krynicki Lantern Brightness Sensor" },
- { 0x12092048, "Housedillon.com MRF49XA Transciever" },
+ { 0x12092048, "Housedillon.com MRF49XA Transceiver" },
{ 0x12092222, "LabConnect Signalgenerator" },
{ 0x12092300, "Keyboardio Keyboardio Model 01 Bootloader" },
{ 0x12092301, "Keyboardio Keyboardio Model 01" },
@@ -18976,10 +18976,10 @@ static const value_string usb_products_vals[] = {
{ 0x1d5060e9, "keyman64 keyboard itercepter" },
{ 0x1d5060ea, "Wiggleport FPGA-based I/O board" },
{ 0x1d5060ec, "Duet 3D Printer Controller" },
- { 0x1d5060f0, "UDAD-T1 data aquisition device (boot)" },
- { 0x1d5060f1, "UDAD-T1 data aquisition device" },
- { 0x1d5060f2, "UDAD-T2 data aquisition device (boot)" },
- { 0x1d5060f3, "UDAD-T2 data aquisition device" },
+ { 0x1d5060f0, "UDAD-T1 data acquisition device (boot)" },
+ { 0x1d5060f1, "UDAD-T1 data acquisition device" },
+ { 0x1d5060f2, "UDAD-T2 data acquisition device (boot)" },
+ { 0x1d5060f3, "UDAD-T2 data acquisition device" },
{ 0x1d5060f4, "Uniti ARC motor controller" },
{ 0x1d5060f5, "EightByEight Blinky Badge (DFU)" },
{ 0x1d5060f6, "EightByEight Blinky Badge" },
@@ -19096,7 +19096,7 @@ static const value_string usb_products_vals[] = {
{ 0x1f870002, "Multi-touch HID Controller" },
{ 0x1f9b0241, "AirView2-EXT" },
{ 0x1fab104d, "ES65" },
- { 0x1fbd0001, "Expert Key - Data aquisition system" },
+ { 0x1fbd0001, "Expert Key - Data acquisition system" },
{ 0x1fc90003, "LPC1343" },
{ 0x1fc9010b, "PR533" },
{ 0x1fc9012b, "i.MX 8M Dual/8M QuadLite/8M Quad Serial Downloader" },
diff --git a/epan/ftypes/ftypes.h b/epan/ftypes/ftypes.h
index 631e7c98d3..7993538bcc 100644
--- a/epan/ftypes/ftypes.h
+++ b/epan/ftypes/ftypes.h
@@ -138,7 +138,7 @@ enum ftrepr {
typedef enum ftrepr ftrepr_t;
-/* Initialize the ftypes subsytem. Called once. */
+/* Initialize the ftypes subsystem. Called once. */
void
ftypes_initialize(void);
diff --git a/epan/ipproto.h b/epan/ipproto.h
index bb57b63eb3..31c5d18aeb 100644
--- a/epan/ipproto.h
+++ b/epan/ipproto.h
@@ -48,7 +48,7 @@
#define IP_PROTO_LEAF1 25
#define IP_PROTO_LEAF2 26
#define IP_PROTO_RDP 27 /* Reliable Data Protocol - RFC908 */
-#define IP_PROTO_IRT 28 /* Internet Reliable Transation - RFC938 */
+#define IP_PROTO_IRT 28 /* Internet Reliable Transaction - RFC938 */
#define IP_PROTO_TP 29 /* tp-4 w/ class negotiation - RFC905 */
#define IP_PROTO_BULK 30 /* Bulk Data Transfer Protocol - RFC969 */
#define IP_PROTO_MFE_NSP 31 /* MFE Network Services Protocol */
diff --git a/epan/dissectors/packet-cdma2k.c b/epan/dissectors/packet-cdma2k.c
index 285275e555..f0fa470798 100644
--- a/epan/dissectors/packet-cdma2k.c
+++ b/epan/dissectors/packet-cdma2k.c
@@ -922,7 +922,7 @@ static const value_string Info_Rec_Types[] = {
};
/* CDMA2K Encrytion Key Size */
static const value_string Enc_Key_Types[] = {
{ 0, "Reserved" },
{ 1, "64 Bits" },
@@ -949,10 +949,10 @@ static const value_string rl_Freq_Offset_Types[] = {
/* CDMA2K Pilot Record Types */
static const value_string Pilot_Rec_Types[] = {
{ 0, "1x Common Pilot With Transmit Diversity" },
- { 1, "1x Auxillary Pilot" },
- { 2, "1x Auxillary Pilot With Transmit Diversity" },
+ { 1, "1x Auxiliary Pilot" },
+ { 2, "1x Auxiliary Pilot With Transmit Diversity" },
{ 3, "3x Common Pilot" },
- { 4, "3x Auxillary Pilot" },
+ { 4, "3x Auxiliary Pilot" },
{ 5, "Reserved" },
{ 6, "Reserved" },
{ 7, "Reserved" },
@@ -4872,7 +4872,7 @@ void proto_register_cdma2k(void)
{ &hf_cdma2k_Msg_Integrity_Sup,
{ "Msg Integrity Supported", "cdma2k.Msg_Integrity_Sup", FT_BOOLEAN, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_cdma2k_Gen_2g_Key,
- { "Generate 2G Encrytion Key", "cdma2k.Gen_2g_Key", FT_BOOLEAN, BASE_NONE, NULL, 0x0, NULL, HFILL } },
+ { "Generate 2G Encryption Key", "cdma2k.Gen_2g_Key", FT_BOOLEAN, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_cdma2k_Register_In_Idle,
{ "Register In Idle State", "cdma2k.Register_In_Idle", FT_BOOLEAN, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_cdma2k_Plcm_Type_Incl,
@@ -4892,7 +4892,7 @@ void proto_register_cdma2k(void)
{ &hf_cdma2k_Pilot_Info_Req_Supported,
{ "Pilot Info Req Supported", "cdma2k.Pilot_Info_Req_Supported", FT_BOOLEAN, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_cdma2k_Enc_Supported,
- { "Encrytion Fields Incl", "cdma2k.Enc_Supported", FT_BOOLEAN, BASE_NONE, NULL, 0x0, NULL, HFILL } },
+ { "Encryption Fields Incl", "cdma2k.Enc_Supported", FT_BOOLEAN, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_cdma2k_Sig_Encrypt_Sup,
{ "Signalling Encryption Supported", "cdma2k.Sig_Encrypt_Sup", FT_UINT8, BASE_HEX_DEC, NULL, 0x0, NULL, HFILL } },
{ &hf_cdma2k_Ui_Encrypt_Sup,
@@ -4950,7 +4950,7 @@ void proto_register_cdma2k(void)
{ &hf_cdma2k_Fsch_Outercode_Offset,
{ "For Sch Outer Code Offset", "cdma2k.Fsch_Outercode_Offset", FT_UINT8, BASE_HEX_DEC, NULL, 0x0, NULL, HFILL } },
{ &hf_cdma2k_Max_Add_Serv_Instance,
- { "Max Additonal Service Identifiers", "cdma2k.Max_Add_Serv_Instance", FT_UINT8, BASE_HEX_DEC, NULL, 0x0, NULL, HFILL } },
+ { "Max Additional Service Identifiers", "cdma2k.Max_Add_Serv_Instance", FT_UINT8, BASE_HEX_DEC, NULL, 0x0, NULL, HFILL } },
{ &hf_cdma2k_Use_Ch_Cfg_Rrm,
{ "Channel Config Req Allowed", "cdma2k.Use_Ch_Cfg_Rrm", FT_BOOLEAN, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_cdma2k_Tx_Pwr_Limit_Incl,
@@ -922,7 +922,7 @@ static const value_string Info_Rec_Types[] = {
};
-/* CDMA2K Encrytion Key Size */
+/* CDMA2K Encryption Key Size */
static const value_string Enc_Key_Types[] = {
{ 0, "Reserved" },
diff --git a/epan/dissectors/packet-zbee-zcl-se.c b/epan/dissectors/packet-zbee-zcl-se.c
index c83a5b846f..3af283af6a 100644
--- a/epan/dissectors/packet-zbee-zcl-se.c
+++ b/epan/dissectors/packet-zbee-zcl-se.c
@@ -9817,7 +9817,7 @@ static int hf_zbee_zcl_calendar_total_number_of_commands = -1;
static int hf_zbee_zcl_calendar_schedule_entry_start_time = -1;
static int hf_zbee_zcl_calendar_schedule_entry_price_tier = -1;
static int hf_zbee_zcl_calendar_schedule_entry_friendly_credit_enable = -1;
-static int hf_zbee_zcl_calendar_schedule_entry_auxilary_load_switch_state = -1;
+static int hf_zbee_zcl_calendar_schedule_entry_auxiliary_load_switch_state = -1;
/* Initialize the subtree pointers */
static gint ett_zbee_zcl_calendar = -1;
@@ -9829,7 +9829,7 @@ static gint ett_zbee_zcl_calendar_season_start_date = -1;
XXX(ZBEE_ZCL_CALENDAR_TYPE_RECEIVED, 0x01, "Received Calendar" ) \
XXX(ZBEE_ZCL_CALENDAR_TYPE_DELIVERED_AND_RECEIVED, 0x02, "Delivered and Received Calendar" ) \
XXX(ZBEE_ZCL_CALENDAR_TYPE_FRIENDLY_CREDIT, 0x03, "Friendly Credit Calendar" ) \
- XXX(ZBEE_ZCL_CALENDAR_TYPE_AUXILARY_LOAD_SWITCH, 0x04, "Auxilary Load Switch Calendar" )
+ XXX(ZBEE_ZCL_CALENDAR_TYPE_AUXILIARY_LOAD_SWITCH, 0x04, "Auxiliary Load Switch Calendar" )
VALUE_STRING_ENUM(zbee_zcl_calendar_type_names);
VALUE_STRING_ARRAY(zbee_zcl_calendar_type_names);
@@ -10259,10 +10259,10 @@ dissect_zcl_calendar_publish_day_profile(tvbuff_t *tvb, proto_tree *tree, guint
*offset += 1;
break;
- /* Auxilary Load Start Time */
- case ZBEE_ZCL_CALENDAR_TYPE_AUXILARY_LOAD_SWITCH:
+ /* Auxiliary Load Start Time */
+ case ZBEE_ZCL_CALENDAR_TYPE_AUXILIARY_LOAD_SWITCH:
/* Price Tier */
- proto_tree_add_item(tree, hf_zbee_zcl_calendar_schedule_entry_auxilary_load_switch_state, tvb, *offset, 1, ENC_NA);
+ proto_tree_add_item(tree, hf_zbee_zcl_calendar_schedule_entry_auxiliary_load_switch_state, tvb, *offset, 1, ENC_NA);
*offset += 1;
break;
}
@@ -10630,8 +10630,8 @@ proto_register_zbee_zcl_calendar(void)
{ "Friendly Credit Enable", "zbee_zcl_se.calendar.schedule_entry.friendly_credit_enable", FT_BOOLEAN, 8, TFS(&tfs_enabled_disabled),
0x00, NULL, HFILL } },
- { &hf_zbee_zcl_calendar_schedule_entry_auxilary_load_switch_state,
- { "Auxilary Load Switch State", "zbee_zcl_se.calendar.schedule_entry.auxilary_load_switch_state", FT_UINT8, BASE_HEX, NULL,
+ { &hf_zbee_zcl_calendar_schedule_entry_auxiliary_load_switch_state,
+ { "Auxiliary Load Switch State", "zbee_zcl_se.calendar.schedule_entry.auxiliary_load_switch_state", FT_UINT8, BASE_HEX, NULL,
0x00, NULL, HFILL } },
};
@@ -10755,7 +10755,7 @@ static int hf_zbee_zcl_daily_schedule_total_number_of_commands = -1;
static int hf_zbee_zcl_daily_schedule_total_number_of_schedule_entries = -1;
static int hf_zbee_zcl_daily_schedule_schedule_entry_start_time = -1;
static int hf_zbee_zcl_daily_schedule_schedule_entry_price_tier = -1;
-static int hf_zbee_zcl_daily_schedule_schedule_entry_auxilary_load_switch_state = -1;
+static int hf_zbee_zcl_daily_schedule_schedule_entry_auxiliary_load_switch_state = -1;
/* Initialize the subtree pointers */
static gint ett_zbee_zcl_daily_schedule = -1;
@@ -10972,7 +10972,7 @@ dissect_zcl_daily_schedule_publish_day_profile(tvbuff_t *tvb, proto_tree *tree,
proto_tree_add_item(tree, hf_zbee_zcl_daily_schedule_schedule_entry_price_tier, tvb, *offset, 1, ENC_NA);
*offset += 1;
/* Auxiliary Load Switch State */
- proto_tree_add_item(tree, hf_zbee_zcl_daily_schedule_schedule_entry_auxilary_load_switch_state, tvb, *offset, 1, ENC_NA);
+ proto_tree_add_item(tree, hf_zbee_zcl_daily_schedule_schedule_entry_auxiliary_load_switch_state, tvb, *offset, 1, ENC_NA);
*offset += 1;
break;
}
@@ -11154,8 +11154,8 @@ proto_register_zbee_zcl_daily_schedule(void)
{ "Price Tier", "zbee_zcl_se.daily_schedule.schedule_entry.price_tier", FT_UINT8, BASE_DEC, NULL,
0x00, NULL, HFILL } },
- { &hf_zbee_zcl_daily_schedule_schedule_entry_auxilary_load_switch_state,
- { "Auxilary Load Switch State", "zbee_zcl_se.daily_schedule.schedule_entry.auxilary_load_switch_state", FT_UINT8, BASE_HEX, NULL,
+ { &hf_zbee_zcl_daily_schedule_schedule_entry_auxiliary_load_switch_state,
+ { "Auxiliary Load Switch State", "zbee_zcl_se.daily_schedule.schedule_entry.auxiliary_load_switch_state", FT_UINT8, BASE_HEX, NULL,
0x00, NULL, HFILL } },
};